@@ -40,7 +40,7 @@ class AsyncInitable:
         self.async_init_finished__event.set()
 
     async def _async_init(self) -> None:
-        """Если дефолтная инициализация не подходит, что переопределите этот метод"""
+        """Если дефолтная инициализация не подходит, то переопределите этот метод"""
         await self._async_init_attrs()
 
     async def _async_init_attrs(self) -> None:
